#!/usr/bin/env node
import clipboardy from 'clipboardy';
import meow from 'meow';
import colors from 'ansi-colors';
import updateNotifier from 'update-notifier';
import importCommonJs from 'import-commonjs';
import path from 'path';
import getStdin from 'get-stdin';
import leftPhalange from 'left-phalange-api';

const cli = meow(
  `
  Usage
    left-phalange <file>
    lp <file>

  Options
    -i, --input           ${colors.cyan('Input Data type')}
    -o, --output          ${colors.cyan('Output Data type')}
    -p, --pretty          ${colors.cyan('Pretty output')}
    -C, --copy            ${colors.cyan('Copy output to clipboard')}
    -h, --help            ${colors.cyan('Show this help info')}
    -v, --version         ${colors.cyan('Show version')}

  Examples
    lp data.toml > data.json
    cat data.yaml | lp -p
  `,
  {
    flags: {
      pretty: {
        type: 'boolean',
        default: false,
        alias: 'p',
      },
      input: {
        alias: 'i',
      },
      output: {
        alias: 'o',
      },
      copy: {
        type: 'boolean',
        default: false,
        alias: 'C',
      },
      help: {
        alias: 'h',
      },
      version: {
        alias: 'v',
      },
    },
  }
);

const require = importCommonJs(import.meta.url);

function update() {
  updateNotifier({pkg: require('../package.json')}).notify();
}

const {load, parse} = leftPhalange;
const {join, isAbsolute} = path;

async function input(cli) {
  const {input, flags} = cli;

  const content = await getStdin();

  if (content) {
    return parse(content, {
      type: flags.input,
    })
  }

  let [file] = input;

  if (file) {
    file = isAbsolute(file) ? file : join(process.cwd(), file);
    return load(file, {
      type: flags.input,
    })
  }
}

const {stringify} = leftPhalange;

function output(cli, data) {
  const {flags} = cli;
  const {output, pretty} = flags;
  const result = stringify(data, {
    type: output,
    pretty,
  });

  return result
}

const {writeSync: copyToClipboard} = clipboardy;

async function main(cli) {
  const data = await input(cli);

  if (typeof data === 'undefined') {
    return cli.showHelp(0)
  }

  const result = output(cli, data);

  const {copy} = cli.flags;

  if (copy) {
    copyToClipboard(result);
    console.log('copied');
  } else {
    console.log(result);
  }
}

update();
main(cli);
